==> foundation-core-app-1.1.0.tgz: package/src/common/hero/variants/split-banner/SplitBanner.tsx <==
import { NsTypography } from '@nuskin/foundation-ui-components';
import { PropsWithChildren, useMemo } from 'react';

import { SplitBannerModes, SplitBannerProps } from '../../types/types';
import { ImageContainer, SBContentContainer, TextContainer } from './SplitBanner.styled';
import { getBasicDATWidthHeight } from '@/common/utils/bynder-util';
import useToggleFontColor from '@/common/hooks/use-toggle-font-color/useToggleFontColor';
import NsCTALinkComponent from '@/common/cta-link/CtaLink';
import { BynderImage } from '@/common/bynder-image/BynderImage';

const suffix = getBasicDATWidthHeight(600, 600, 'scale');
/**
 * SplitBanner renders an image and text panels on opposite sides, which can be controller via imageAlignment.
 * this is hero variant, available in ns_hero global field
 */
const SplitBanner = ({ heroItem }: { heroItem: PropsWithChildren<SplitBannerProps> }) => {
    // TODO: discuss and standardize prop grouping into types. I.e. HeroText { title, description }, HighlightConfig { imageAlignment }.
    const {
        header,
        description,
        theme = SplitBannerModes.default,
        fontColor,
        backgroundColor = 'transparent',
        image,
        imageAlignment = 'left',
        callToAction,
        liveTags,
        dataTestId = 'split-banner'
    } = heroItem;
    const resolvedFontColor = useToggleFontColor(fontColor);

    const containerClassName = useMemo(() => {
        return [`image-align-${imageAlignment}`, `mode-${theme}`].join(' ');
    }, [theme, imageAlignment]);

    // TODO: Replace w/ finalized CFT CTA button
    const cta = useMemo(() => {
        return callToAction?.url && callToAction?.text ? (
            <div {...liveTags?.callToAction} className="mt-4" data-testid="cta">
                <NsCTALinkComponent
                    ctaProps={{ ...callToAction, color: fontColor ? 'secondary' : 'primary' }}
                />
            </div>
        ) : (
            <></>
        );
    }, [callToAction, liveTags?.callToAction, fontColor]);

    // TODO: We should be able to render h1 tags but not be bound to its styles (size and weight).
    const textContent = useMemo(() => {
        const titleVariant = theme === SplitBannerModes.default ? 'h5' : 'h4';
        const descriptionVariant = theme === SplitBannerModes.default ? 'body-l' : 'body-xl';
        const conditionalTitle = header ? (
            <div data-testid="title" {...liveTags?.header}>
                <NsTypography
                    className="title"
                    weight="bold"
                    colorOverride={resolvedFontColor}
                    variant={titleVariant}
                >
                    {header}
                </NsTypography>
            </div>
        ) : (
            <></>
        );

        const conditionalDescription = description ? (
            <div data-testid="description" {...liveTags?.description}>
                <NsTypography
                    weight="normal"
                    className="description !mx-0"
                    colorOverride={resolvedFontColor}
                    variant={descriptionVariant}
                >
                    {description}
                </NsTypography>
            </div>
        ) : (
            <></>
        );

        return (
            <>
                {conditionalTitle}
                {conditionalDescription}
            </>
        );
    }, [theme, header, liveTags?.header, liveTags?.description, resolvedFontColor, description]);
    const output = useMemo(() => {
        return (
            <SBContentContainer backgroundColor={backgroundColor} className={containerClassName}>
                <ImageContainer className="image-container">
                    <BynderImage imageText={image} suffix={suffix} className="split-banner-image" />
                </ImageContainer>
                <TextContainer className="text-container">
                    {textContent}
                    {cta}
                </TextContainer>
            </SBContentContainer>
        );
    }, [backgroundColor, containerClassName, image, textContent, cta]);

    return (
        <section className="split-banner" data-testid={dataTestId}>
            {output}
        </section>
    );
};

export default SplitBanner;

==> foundation-core-app-1.2.0.tgz: package/src/common/hero/variants/split-banner/SplitBanner.tsx <==
import { NsTypography } from '@nuskin/foundation-ui-components';
import { PropsWithChildren, useMemo } from 'react';

import { SplitBannerModes, SplitBannerProps } from '../../types/types';
import { ImageContainer, SBContentContainer, TextContainer } from './SplitBanner.styled';
import { getBasicDATWidthHeight } from '../../../utils/bynder-util';
import useToggleFontColor from '../../../hooks/use-toggle-font-color/useToggleFontColor';
import NsCTALinkComponent from '../../../cta-link/CtaLink';
import { BynderImage } from '../../../bynder-image/BynderImage';

const suffix = getBasicDATWidthHeight(600, 600, 'scale');
/**
 * SplitBanner renders an image and text panels on opposite sides, which can be controller via imageAlignment.
 * this is hero variant, available in ns_hero global field
 */
const SplitBanner = ({ heroItem }: { heroItem: PropsWithChildren<SplitBannerProps> }) => {
    // TODO: discuss and standardize prop grouping into types. I.e. HeroText { title, description }, HighlightConfig { imageAlignment }.
    const {
        header,
        description,
        theme = SplitBannerModes.default,
        fontColor,
        backgroundColor = 'transparent',
        image,
        imageAlignment = 'left',
        callToAction,
        liveTags,
        dataTestId = 'split-banner'
    } = heroItem;
    const resolvedFontColor = useToggleFontColor(fontColor);

    const containerClassName = useMemo(() => {
        return [`image-align-${imageAlignment}`, `mode-${theme}`].join(' ');
    }, [theme, imageAlignment]);

    // TODO: Replace w/ finalized CFT CTA button
    const cta = useMemo(() => {
        return callToAction?.url && callToAction?.text ? (
            <div {...liveTags?.callToAction} className="mt-4" data-testid="cta">
                <NsCTALinkComponent
                    ctaProps={{ ...callToAction, color: fontColor ? 'secondary' : 'primary' }}
                />
            </div>
        ) : (
            <></>
        );
    }, [callToAction, liveTags?.callToAction, fontColor]);

    // TODO: We should be able to render h1 tags but not be bound to its styles (size and weight).
    const textContent = useMemo(() => {
        const titleVariant = theme === SplitBannerModes.default ? 'h5' : 'h4';
        const descriptionVariant = theme === SplitBannerModes.default ? 'body-l' : 'body-xl';
        const conditionalTitle = header ? (
            <div data-testid="title" {...liveTags?.header}>
                <NsTypography
                    className="title"
                    weight="bold"
                    colorOverride={resolvedFontColor}
                    variant={titleVariant}
                >
                    {header}
                </NsTypography>
            </div>
        ) : (
            <></>
        );

        const conditionalDescription = description ? (
            <div data-testid="description" {...liveTags?.description}>
                <NsTypography
                    weight="normal"
                    className="description !mx-0"
                    colorOverride={resolvedFontColor}
                    variant={descriptionVariant}
                >
                    {description}
                </NsTypography>
            </div>
        ) : (
            <></>
        );

        return (
            <>
                {conditionalTitle}
                {conditionalDescription}
            </>
        );
    }, [theme, header, liveTags?.header, liveTags?.description, resolvedFontColor, description]);
    const output = useMemo(() => {
        return (
            <SBContentContainer backgroundColor={backgroundColor} className={containerClassName}>
                <ImageContainer className="image-container">
                    <BynderImage imageText={image} suffix={suffix} className="split-banner-image" />
                </ImageContainer>
                <TextContainer className="text-container">
                    {textContent}
                    {cta}
                </TextContainer>
            </SBContentContainer>
        );
    }, [backgroundColor, containerClassName, image, textContent, cta]);

    return (
        <section className="split-banner" data-testid={dataTestId}>
            {output}
        </section>
    );
};

export default SplitBanner;
